==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/ImportedClassSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassInAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassInAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ImportedClass;
import io.ciera.tool.sql.ooaofooa.subsystem.ImportedClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.List;


public class ImportedClassSetImpl extends InstanceSet<ImportedClassSet,ImportedClass> implements ImportedClassSet {

    // attributes
    @Override
    public void setObj_Name( String m_Obj_Name ) throws XtumlException {
        for ( ImportedClass importedclass : this ) importedclass.setObj_Name( m_Obj_Name );
    }
    @Override
    public void setObj_KL( String m_Obj_KL ) throws XtumlException {
        for ( ImportedClass importedclass : this ) importedclass.setObj_KL( m_Obj_KL );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ImportedClass importedclass : this ) importedclass.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setSS_IDdeprecated( UniqueId m_SS_IDdeprecated ) throws XtumlException {
        for ( ImportedClass importedclass : this ) importedclass.setSS_IDdeprecated( m_SS_IDdeprecated );
    }
    @Override
    public void setModl_Typ( int m_Modl_Typ ) throws XtumlException {
        for ( ImportedClass importedclass : this ) importedclass.setModl_Typ( m_Modl_Typ );
    }
    @Override
    public void setIObj_ID( UniqueId ref_IObj_ID ) throws XtumlException {
        for ( ImportedClass importedclass : this ) importedclass.setIObj_ID( ref_IObj_ID );
    }


    // selections
    @Override
    public ModelClassSet R101_represents_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( ImportedClass importedclass : this ) modelclassset.add( importedclass.R101_represents_ModelClass() );
        return modelclassset;
    }
    @Override
    public ClassInAssociationSet R202_is_used_for_spanning_associations_as_ClassInAssociation() throws XtumlException {
        ClassInAssociationSet classinassociationset = new ClassInAssociationSetImpl();
        for ( ImportedClass importedclass : this ) classinassociationset.addAll( importedclass.R202_is_used_for_spanning_associations_as_ClassInAssociation() );
        return classinassociationset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( ImportedClass importedclass : this ) packageableelementset.add( importedclass.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }


    @Override
    public ImportedClass nullElement() {
        return ImportedClassImpl.EMPTY_IMPORTEDCLASS;
    }

    @Override
    public ImportedClassSet emptySet() {
      return new ImportedClassSetImpl();
    }

    @Override
    public ImportedClassSet value() {
        return this;
    }

    @Override
    public List<ImportedClass> elements() {
        return Arrays.asList(toArray(new ImportedClass[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/ImportedClassSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassInAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassInAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ImportedClass;
import io.ciera.tool.sql.ooaofooa.subsystem.ImportedClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ImportedClassSetImpl extends InstanceSet<ImportedClassSet,ImportedClass> implements ImportedClassSet {

    public ImportedClassSetImpl() {
    }

    public ImportedClassSetImpl(Comparator<? super ImportedClass> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ImportedClass importedclass : this ) importedclass.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setSS_IDdeprecated( UniqueId m_SS_IDdeprecated ) throws XtumlException {
        for ( ImportedClass importedclass : this ) importedclass.setSS_IDdeprecated( m_SS_IDdeprecated );
    }
    @Override
    public void setObj_KL( String m_Obj_KL ) throws XtumlException {
        for ( ImportedClass importedclass : this ) importedclass.setObj_KL( m_Obj_KL );
    }
    @Override
    public void setIObj_ID( UniqueId ref_IObj_ID ) throws XtumlException {
        for ( ImportedClass importedclass : this ) importedclass.setIObj_ID( ref_IObj_ID );
    }
    @Override
    public void setModl_Typ( int m_Modl_Typ ) throws XtumlException {
        for ( ImportedClass importedclass : this ) importedclass.setModl_Typ( m_Modl_Typ );
    }
    @Override
    public void setObj_Name( String m_Obj_Name ) throws XtumlException {
        for ( ImportedClass importedclass : this ) importedclass.setObj_Name( m_Obj_Name );
    }


    // selections
    @Override
    public ModelClassSet R101_represents_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( ImportedClass importedclass : this ) modelclassset.add( importedclass.R101_represents_ModelClass() );
        return modelclassset;
    }
    @Override
    public ClassInAssociationSet R202_is_used_for_spanning_associations_as_ClassInAssociation() throws XtumlException {
        ClassInAssociationSet classinassociationset = new ClassInAssociationSetImpl();
        for ( ImportedClass importedclass : this ) classinassociationset.addAll( importedclass.R202_is_used_for_spanning_associations_as_ClassInAssociation() );
        return classinassociationset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( ImportedClass importedclass : this ) packageableelementset.add( importedclass.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }


    @Override
    public ImportedClass nullElement() {
        return ImportedClassImpl.EMPTY_IMPORTEDCLASS;
    }

    @Override
    public ImportedClassSet emptySet() {
      return new ImportedClassSetImpl();
    }

    @Override
    public ImportedClassSet emptySet(Comparator<? super ImportedClass> comp) {
      return new ImportedClassSetImpl(comp);
    }

    @Override
    public ImportedClassSet value() {
        return this;
    }

    @Override
    public List<ImportedClass> elements() {
        return Arrays.asList(toArray(new ImportedClass[0]));
    }

}
